@@ -54,7 +54,12 @@ class accuinsight(Common):
             shap_on = True
             if self.feature_name is None:
                 try:
-                    feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
+                    if self.data is not None:
+                        feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name,
+                                                        data=self.data)
+                        self.data = None
+                    else:
+                        feature_name = get.feature_name(self.save_path, self.StorageInfo, self.target_name)
 
                 except:
                     pass      # when user did not use <get_file> or <set_feature> function
