@@ -6,11 +6,10 @@ from Accuinsight.modeler.core import ModelType
 
 
 def as_array(dat):
-    if 'ndarray' in str(type(dat)):
-        pass
-    else:
+    if 'ndarray' not in str(type(dat)):
         dat = np.array(dat)
-    return(dat) 
+
+    return dat
 
 
 def get_model_name(model):
@@ -23,7 +22,7 @@ def get_model_name(model):
     elif '(' and ')' in model_name:
         model_name = model_name.split('(')[0]
         
-    return(model_name)
+    return model_name
 
 
 def shap_value(model, dat, feature_name):
