@@ -2,6 +2,7 @@ from collections import OrderedDict
 import numpy as np
 from scipy import interpolate
 
+
 def delete_nan(lst):
     if np.isnan(lst).any():
         idx = np.where(np.isnan(lst))[0].tolist()
@@ -9,18 +10,21 @@ def delete_nan(lst):
         for i in idx:
             lst.pop(i)
     
-    return(lst)
-                       
+    return lst
+
+
 def sort(x):
     sort_result = np.sort(x)[::-1]
     sort_idx = x.argsort()[::-1]
-    return({'x': sort_result, 'idx':sort_idx})
+    return {'x': sort_result, 'idx':sort_idx}
+
 
 def moving_average(a, n) :
     cumsum = np.cumsum(a, dtype=float)
     cumsum[n:] = cumsum[n:] - cumsum[:-n]
     return cumsum[n - 1:] / n
 
+
 def cal_confusion(y_test_vec, y_score_vec, force_diag = True):
     results = OrderedDict()
     y_score_vec_sort = sort(y_score_vec)
@@ -40,12 +44,13 @@ def cal_confusion(y_test_vec, y_score_vec, force_diag = True):
         results['TPR'] = np.r_[np.array(0), results['TPR']]
         results['FPR'] = np.r_[np.array(0), results['FPR']]
         results['PPV'] = np.r_[results['PPV'][0], results['PPV']]
-    return(results)
+    return results
+
 
 def cal_auc(tpr, ppv):
     idx = tpr.argsort(kind='stable')
-    auc = np.sum(np.diff(tpr[idx]) * moving_average(ppv[idx], 2))
-    return(auc)
+    return np.sum(np.diff(tpr[idx]) * moving_average(ppv[idx], 2))
+
 
 def multi_pr(y_test, y_score):
     recall = OrderedDict()
