@@ -7,7 +7,6 @@ from Accuinsight.modeler.core.Run.RunInfo.RunInfo import get_or_create_run_direc
 
 
 def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
-    
     """
     ML 모델 저장을 위한 `add_experiment()`, 또는 DL 모델 저장을 위한 `autolog()` 실행시 output 저장을 위한 경로 생성 함수
 
@@ -35,8 +34,7 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
     except IndexError:
         # ML
         prefix_path = 'results'+ '-' + get.model_type(model_name) + '/'
-    
-    
+
     if not os.path.isdir(prefix_path):
         try:
             os.mkdir(prefix_path)
@@ -45,7 +43,6 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
     
     os.chdir(prefix_path)
 
-
     # make dir 'best_model'
     save_best_model = 'best-model' # train 중 가장 좋은 모델의 weight 정보 저장
     save_model_path = home + save_best_model + '/'
@@ -61,6 +58,7 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
     json_path_visual = 'for-visual-json'    # classification일 경우, json_path 하나 더 생성됨
     json_path_shap = 'shap-value-json'      # shap_value(feature_contribution) json 파일 저장하는 path(ML/DL 공통)
 
+    path_list = list()
     if 'keras' in get.model_type(model_name) or 'tf' in get.model_type(model_name) or 'pytorch' in get.model_type(model_name):
         csv_path_visual = 'for-visual-csv'            # learning history가 저장되는 csv_path
 
@@ -90,7 +88,7 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
     
     ## 모델별 trial_num 생성
     if 'csv_path_visual' in locals():
-        trial_num_list = [[get.trial_number_all(i, 'json') for i in path_list if 'json' in i]]
+        trial_num_list = list([get.trial_number_all(i, 'json') for i in path_list if 'json' in i])
         trial_num_list.append([get.trial_number_all(i, 'csv') for i in path_list if 'csv' in i])
         merged_list = list(itertools.chain.from_iterable(trial_num_list))
         merged_list = list(map(int, merged_list))
@@ -151,9 +149,12 @@ def get_file_path(model_name, root_path = RUN_ROOT_PATH, **kwargs):
                     'visual_json_full': home + prefix_path + json_file_name_visual,
                     'shap_json_full': home + prefix_path + json_file_name_shap}
 
+    else:
+        dir_dict = dict()
+
     # 기존 path로 변경
     os.chdir(original_path)
     
-    return(dir_dict)
+    return dir_dict
 
 
